(v0.6.0)=
### 0.6.0 {small}`1 May, 2018`

- compatibility with Seurat converter
- tremendous speedup for {meth}`~anndata.AnnData.concatenate`
- bug fix for deep copy of unstructured annotation after slicing
- bug fix for reading HDF5 stored single-category annotations
- `'outer join'` concatenation: adds zeros for concatenation of sparse data and nans for dense data
- better memory efficiency in loom exports
